@@ -236,8 +236,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 body: TypedBody<CreateParams>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let params = body.into_inner();
@@ -274,8 +273,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -313,8 +311,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<AddOrRemoveItemParams>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -353,8 +350,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<AddOrRemoveItemParams>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -392,8 +388,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -432,8 +427,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<Contact>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -472,8 +466,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<Address>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -512,8 +505,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<FulfillmentTypeSelection>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -552,8 +544,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -592,8 +583,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>>, HttpError> {
                 let path_params = path.into_inner();
@@ -641,8 +631,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
@@ -680,8 +669,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
@@ -725,8 +713,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<CorrelationIdParam>,
                 body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
@@ -769,8 +756,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
-                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data,
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
